// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  name  = Dominique COLLIN
//	mail  = dnilloc@sfr.fr
//	adress= 18 rue Joseph Cadei - 06100 , Nice - France.
//	Phone = 04.93.37.69.13  portable = 06.48.85.12.62.
//  Work  = Lyce Professionnel Pasteur
//				25 rue du Proofesseur Delvalle - 06000, Nice.
//	date  = Juin 2010.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Objet = Gnomonique thorique
// Lignes horaires Temporaires en usage dans l'antiquit.
// Traduction de l'article de WA CADELL (date : 1818).
//
//	PLAN TANGENT AU POLE SUD DE LA SPHERE CELESTE // Projection centrale
//	Figure 1, planche II, Trans. vol.VIII, page 83, (Royal Society of Edinburgh, 1818)
//	Latitude : phi = 6634' Nord.
// ------------------------------------------------------------------------------------------------
// Begining of Asymptote Figure.
// Cet en-tte permet de visualiser l'image 3D mme si le visualisation PDF ne traite pas la PRC.
// ------------------------------------------------------------------------------------------------
import settings;
	leftbutton=new string[] {"Rotation","Agrandissement","Shift","Pan"};
	middlebutton=new string[] {"Menu"};
	rightbutton=new string[] {"Agrandissement/menu","RotateX","RotateY","RotateZ"};
	wheelup=new string[] {"ZoomIn"};
	wheeldown=new string[] {"ZoomOut"};
//
 	settings.batchView=true;
 	settings.tex="pdflatex";
	settings.render=2;
	//settings.inlineimage=true;
	settings.embed=true;
	settings.outformat='pdf';
	settings.toolbar=true;
	settings.prc=true;
	viewportmargin=(1,1);
	viewportsize=(300pt,0);
	//defaultfilename='fig_Michnik_n2p4_plan-Tangent-au-Pole';
// ------------------------------------------------------------------------------------------------
// ********Appel des fichiers de macros....************************************* <----
import graph3;
import solids;
import math;
import labelpath3;
usepackage("relsize");//rgle la taille du texte...

// taille de la figure
size(15cm,0);
scale(true);

// ********REGLAGES de la vue / perspective...********************************** <----
currentprojection=orthographic(-1/10000,0,10);
currentlight=White;

// ********DECLARATION des VARIABLES et des PARAMETRES...***********************
real R, phi, epsilon, delta, L, n, k, K ;

R=1					; // rayon de la sphre cleste	 			  				<----
phi= 66+34/60		; // latitude gographique du lieu du cadran solaire
epsilon=23+26/60	; // obliquit de l'cliptique / valeur maximum de delta.
K=-cot(phi*pi/180)	; 
// ***************************************************************************** //
//	Les points sur la sphre
triple origine 	=	(0,0,0);	// Centre de la sphre.
triple poleNord =	(0,0,R);	// ple Nord P sur la sphre cleste.
triple poleSud  =	(0,0,-R);	// ple Sud P' sur la sphre cleste.
triple EqSud	=	(R,0,0);	// Point sud quatorial.
triple EqEst	=	(0,R,0);	// Point quatorial est.
triple Zenith   =   (R*Sin(90-phi),0,R*Sin(phi)); // Znith du lieu de latitude phi.
triple OrigineHectemories = R*(Cos(90-phi),0,-Sin(90-phi)); // Intersection commune des Hectmories

//~~~~~~~~~ CONSTRUCTION de la SPHERE CELESTE ~~~~~~~~~ 
revolution b=sphere(origine,R);
draw(surface(b),palegreen+opacity(.85)); // si la figure relle de Cadell est souhaite, commenter cette ligne.

//~~~~~~~~~ CONSTRUCTION du PLAN TANGENT AU PLE SUD DE LA SPHERE CELESTE ~~~~~~~~~ 
surface plantgtpol = shift(poleSud)*scale3(R*Tan(90-10))*unitdisk; // la limite max du disque est donne par delta=10.

// ******** CONSTRUCTIONS des HECTEMORIES SUR LA SPHERE CELESTE ~~~~~~~~~ 
for (k=1 ; k<6; k=k+1) {
n=6/k ;	// heure temporaire (n=6/k)
// CONSTRUCTION des HECTEMORIES sur la SPHERE CELESTE par le calcul
real x(real t) {return R*Cos(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real y(real t) {return R*Sin(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real z(real t) {return R*K*Cos(n*t)/sqrt(1+(K*Cos(n*t))^2) 	;}

path3 ps=graph(x,y,z,0,360, operator ..); // les lignes hectmorales I et II seront incompltes...
draw(ps,1/2bp+k*blue);
	// ******** CONSTRUCTION des HECTEMORIES dans le PLAN TANGENT AU POLE DE LA SPHERE CELESTE par INTERSECTION
for( L = -k*30 ; L < k*30; L=L+1/5 ) {
	delta = aTan(K*Cos(n*L));											// <----
	// Un point de l'Hectmorie sur la surface de la sphre.
	triple S = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta),  Sin(delta) );
	// On dfinit la droite (OS) pour matrialiser le principe de la projection centrale...
	path3 ligne = origine--S--10*R*S;
	// CONSTRUCTION de S2, projection centrale de S sur le plan tangent au ple de la sphre.
	triple[] S2=intersectionpoints(ligne,surface(plantgtpol));
	dot(S2,0.28mm+red);
	}
}
//~~~~~~~~~ CONSTRUCTION des ARCS de GRAND CERCLE et des PETITS CERCLES ~~~~~~~~~ 
//~~~~~~~~~ arcs de grand cercle ~~~~~~~~~ 
path3 meridien			= arc(origine, R, 0, 0, 90+(90-phi), 0); // Cercle mridien
path3 premier_vertical	= arc(origine, (0,-R,0), (0,R,0), OrigineHectemories, CW); // cercle du premier vertical
path3 cerclehori = circle(O, R, rotate((90-phi),Y)*Z); // Cercle horizon

//~~~~~~~~~ petits cercles ~~~~~~~~~ 
//~~~~~~~~~ Centre des cercles Limites - Rayon des cercles Limites : sur la sphre ~~~~~~~~~ 
real Rmax = R*Cos(90-phi);
real Rmin = R*Cos(-(90-phi));

triple Cmax = -(0,0,R*Sin(90-phi) );
triple Cmin = -(0,0,R*Sin(-(90-phi)) );

path3 cerclemax = shift(Cmax)*scale3(Rmax)*unitcircle3;	//circle(Cmax, Rmax, Z);
path3 cerclemin = shift(Cmin)*scale3(Rmin)*unitcircle3;	//circle(Cmin, Rmin, Z);

//~~~~~~~~~ CONSTRUCTION des COLLURES des SOLSTICES sur la SPHERE CELESTE ~~~~~~~~~
real Rsolstice 	= R*Cos(epsilon);
real zsolstice 	= R*Sin(epsilon);

triple centre_ete = -(0,0,zsolstice);
triple centre_hiv = -(0,0,-zsolstice);

path3 ETE = shift(centre_ete)*scale3(Rsolstice)*unitcircle3;
path3 HIV = shift(centre_hiv)*scale3(Rsolstice)*unitcircle3;

//~~~~~~~~~ CONSTRUCTIONS COLLURE d'ETE et CERCLE LIMITE BOREAL dans le PLAN TANGENT AU POLE ~~~~~~~~~
//	Projection centrale du solstice d't.
real R2max = R*Tan(phi);				// rayon du cercle limite boral des hectmories.
real Rsolsticeete = R*Tan(90-epsilon);	// rayon du cercle du solstice d't dans le plan.

path3 cerclemax = circle(poleSud, R2max, Z);
path3 cerclesolsticeete = circle(poleSud, Rsolsticeete, Z); //si phi=90-epsilon, les cercles max et solstice t, sont confondus.

// trac de la ligne d'horizon, projection centrale du cercle horizon..
delta=10; // dclinaison pour dlimiter la figure.
triple K1=(R*Tan(phi), sqrt((R*Tan(90-delta))^2-(R*Tan(phi))^2) ,-R);
triple K2=(R*Tan(phi), -sqrt((R*Tan(90-delta))^2-(R*Tan(phi))^2) ,-R);

// Point commun des projections des hectmories sur le plan tangent.
triple I1=(R*Tan(phi),0,-R) ;

// Trac des faisceaux de lignes horaires quinoxiales (temps vrai) dans le plan tangent au pole.
int j;
for(j=0;j<=90*4;j=j+15) {
	triple Mj=(R*Tan(90-delta)*Cos(j), R*Tan(90-delta)*Sin(j), -R);
	//dot(Mj,black);
	draw(poleSud--Mj,black);
}

//TRACAGE DES SEGMENTS ET DES FIGURES...
// sur la sphre cleste
draw(origine--poleSud,white+dashed);
draw(origine--EqSud,white+dashed);
draw(origine--I1,black+dashed+1/4bp,Arrow3);	// rayon OI1.

draw(meridien,1bp+red);							// MERIDIEN
draw(premier_vertical,1/2bp+green);				// PREMIER VERTICAL
draw(scale3(R)*unitcircle3,red);				// EQUATEUR
draw(cerclehori,0.75bp+3yellow);				// HORIZON
draw(ETE,dashed+1.5yellow);						// colure dt
draw(HIV,dashed+1.5yellow);						// colure d'hiver
//draw(cerclemax,0.75bp+dotted+3blue);
//draw(cerclemin,0.75bp+dotted+3blue);

// dans le plan tangent au pole
draw(K1--K2,red);
draw(shift(poleSud)*scale3(I1.x)*unitcircle3,black);			// Projection centrale du colure d'hiver
draw(shift(poleSud)*scale3(R*Tan(90-delta))*unitcircle3,black); // cercle maximal juste pour dlimiter les projections des hectmories
draw(cerclesolsticeete,dashed+3*yellow);						// Colure d't dans le plan tangent au pole
draw(shift(poleSud)*scale3(R)*unitcircle3,dashed+black);		// cercle de rayon la sphre cleste - dans le plan tangent au pole sud...

// TRAAGE DES POINTS
dot(origine);
dot(poleNord,2bp+green);
dot(poleSud,2bp+green);
dot(EqSud,1.5bp+green);
dot(EqEst,1.5bp+green);
dot(Zenith,1.5bp+yellow);
dot(OrigineHectemories,2bp+blue);

//dot(K1,red);
//dot(K2,red);
dot(I1,red);

// ETIQUETTES
label("{\relsize{-3}{$O$}}", origine,NW);
label("{\relsize{-3}{$P$}}", poleNord,0.4NW);
label("{\relsize{-3}{$Z$}}", Zenith,0.5N);
label("{\relsize{-3}{$E$}}", EqSud,0.5NW);
label("{\relsize{-3}{$Est$}}", EqEst,NW);
label("{\relsize{-4}{$I$}}", OrigineHectemories,S);

// Le repre Oxyz...
limits(O,6*R*X+6*R*Y+3/2*R*Z);
axes3("$x$","$y$","$z$",Arrow3);

/*
string txt1="Solstice d'\'et\'e"; 
string txt2="Cercle bor\'eal limite des het\'emories"; 

draw(labelpath(txt1,subpath(cerclesolsticeete,0,1/4),angle=200));
draw(labelpath(txt2,subpath(cerclemax,0,1),angle=200,optional=rotate(-90,X)*Z) );
*/