// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  name  = Dominique COLLIN
//	mail  = dnilloc@sfr.fr
//	adress= 18 rue Joseph Cadei - 06100 , Nice - France.
//	Phone = 04.93.37.69.13  portable = 06.48.85.12.62.
//  Work  = Lyce Professionnel Pasteur
//			25 rue du Proofesseur Delvalle - 06000, Nice.
//	date  = Juin 2010.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Objet = Gnomonique thorique
// Lignes horaires Temporaire en usage dans l'antiquit.
// Reprsentation des diffrentes projection centrale des hectmories.
//
//	PLAN TANGENT AU POLE SUD CELESTE // Projection centrale
//	Figure de W.A. CADELL (1816/1818), dans son article en page 64.
//	Latitude : phi = 6634' Nord.
// ------------------------------------------------------------------------------------------------
// Begining of Asymptote Figure.
// Cet en-tte permet de visualiser l'image 3D mme si le visualisation PDF ne traite pas la PRC.
// ------------------------------------------------------------------------------------------------
import settings;
	leftbutton=new string[] {"Rotation","Agrandissement","Shift","Pan"};
	middlebutton=new string[] {"Menu"};
	rightbutton=new string[] {"Agrandissement/menu","RotateX","RotateY","RotateZ"};
	wheelup=new string[] {"ZoomIn"};
	wheeldown=new string[] {"ZoomOut"};
//
 	settings.batchView=true;
 	settings.tex="pdflatex";
	settings.render=2;
	//settings.inlineimage=true;
	settings.embed=true;
	settings.outformat='pdf';
	settings.toolbar=true;
	settings.prc=true;
	viewportmargin=(1,1);
	viewportsize=(300pt,0);
	//defaultfilename='figure_cadell_p64';
// ------------------------------------------------------------------------------------------------
// ********Appel des fichiers de macros....************************************* <----
import graph3;
import solids;
import math;
import labelpath3;
usepackage("relsize");//rgle la taille du texte...

// taille de la figure
size(10cm,0);
scale(true);

// ********REGLAGES de la vue / perspective...********************************** <----
currentprojection=orthographic(-0.00000000001,0,20);; //(2,1,1)
currentlight=White;

// ********DECLARATION des variables et des paramtres...***********************
real R, phi, epsilon, delta, deltaS, L, n, k, K ;

R=1					; // rayon de la sphre cleste	 			  				<----
phi= 66+34/60		; // latitude gographique du lieu du cadran solaire
epsilon=23+26/60	; // obliquit de l'cliptique / valeur maximum de delta.
K=-cot(phi*pi/180)	; 
// ***************************************************************************** //
//	Les points sur la sphre
triple origine 	=	(0,0,0);	// Centre de la sphre.
triple poleNord =	(0,0,R);	// ple Nord P sur la sphre cleste.
triple poleSud  =	(0,0,-R);	// ple Sud P' sur la sphre cleste.
triple EqSud	=	(R,0,0);	// Point sud quatorial.
triple EqEst	=	(0,R,0);	// Point quatorial est.
triple Zenith   =   (R*Sin(90-phi),0,R*Sin(phi)); // Znith du lieu de latitude phi.
triple OrigineHectemories = R*(Cos(90-phi),0,-Sin(90-phi)); // Intersection commune des Hectmories

//~~~~~~~~~ CONSTRUCTION de la SPHERE CELESTE ~~~~~~~~~ 
revolution b=sphere(origine,R);
//~~~~~~~~~ CONSTRUCTION du PLAN TANGENT AU PLE SUD DE LA SPHERE CELESTE ~~~~~~~~~ 
// pour le rayon du disque on prend arbitrairement delta=10...de la sorte : PN=5.67 units.
surface plantgtpol = shift(poleSud)*scale3(R*Tan(90-10))*unitdisk;

// ******** CONSTRUCTIONS des HECTEMORIES SUR LA SPHERE CELESTE ~~~~~~~~~ 
// ******** CONSTRUCTION de l'HECTEMORIES sur le PLAN TANGENT AU POLE DE LA SPHERE CELESTE par INTERSECTION

//for (k=1 ; k<6; k=k+1) {
k=3;
n=6/k ;	// heure temporaire (n=6/k)
// CONSTRUCTION des HECTEMORIES sur la SPHERE CELESTE par le calcul

for( L = 0 ; L < 91; L=L+1/10 ) {
	delta = aTan(K*Cos(n*L));											// <----
	// CONSTRUCTION des PROJECTION CENTRALE DES HECTEMORIES sur le PLAN TANGENT AU POLE DE LA SPHERE
	// Un point de l'Hectmorie sur la surface de la sphre.
	triple S = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta),  Sin(delta) );
	// On dfinit la droite (OS) pour matrialiser le principe de la projection centrale...
	path3 ligne = origine--S--10*R*S;
	// CONSTRUCTION de S2, projection centrale de S sur le plan tangent au ple de la sphre.
	triple[] S2=intersectionpoints(ligne,surface(plantgtpol));
	dot(S2,0.28mm+red);
	}
//}
//~~~~~~~~~ CONSTRUCTION des ARCS de GRAND CERCLE et des PETITS CERCLES ~~~~~~~~~ 
// Quelques points pour la construction de la figure
triple H=(R*Tan(phi),0,-R) ; // projection du point d'intersection des hectmories sur la sphre cleste.
k=3 ; n = 6/k ;
L=25+3;
deltaS=aTan(-K*Cos(n*L));
triple Sh = R*( Cos(L)*Cos(deltaS),Sin(L)*Cos(deltaS), - Sin(deltaS) ); // Un point de l'hectmorie III sur la sphre
path3 ligne = origine--Sh--10*R*Sh;
triple[] Sh1=intersectionpoints(ligne,surface(plantgtpol));// Point de l'hectmorie III sur le plan tangent  la sphre
draw(poleSud--Sh1[0],black);
// trac de la ligne d'horizon, projection centrale du cercle horizon..
delta=10;
triple K1=(R*Tan(phi), sqrt((R*Tan(90-delta))^2-(R*Tan(phi))^2) ,-R);
// trac du mridien PN...
triple N=(R*Tan(90-delta),0,-R);
int j=45;
triple Mj=(R*Tan(90-delta)*Cos(j), R*Tan(90-delta)*Sin(j), -R);
triple[] D=intersectionpoints(poleSud--Mj,shift(poleSud)*scale3(H.x)*unitcircle3);
triple[] Dp1=intersectionpoints(poleSud--Mj,H--K1);
triple Dp2=(sqrt(Dp1[0].x^2+Dp1[0].y^2),0,-R);
triple M=(Sh1[0].x,0,-R);

// Marquage de quelques points...
dot(Sh1,red);
dot(K1,red);
dot(H,red);
dot(N,red);
dot(M,green);
dot(poleSud,black);

// Trac de quelques segments 
draw(poleSud--Mj,black); // trac de la ligne horaire de temps equinoxial 3h.
draw(M--Sh1[0],black);
draw(H--K1,1/2bp+black,Arrow3);		// Ligne HO.
draw(poleSud--N,1/2bp+black,Arrow3);	// Ligne PN. est aussi le rayon

// Les arcs de cercle de la figure de Cadell, page 64 de son article
draw(arc(poleSud, H, D[0], CCW),black);
draw(arc(poleSud, N, K1, CCW),black);
triple[] Sp=intersectionpoints(H--K1,shift(poleSud)*scale3(R*Tan(90-deltaS))*unitcircle3);// 
draw(arc(poleSud, (sqrt(Sh1[0].x^2+Sh1[0].y^2),0,-R), Sp[0], CCW),black);
draw(arc(poleSud, Dp2, Dp1[0], CCW),black);
draw(arc(poleSud, (R,0,-R), R*(Cos(j),Sin(j),-R), CCW),black+dashed);

// Les tiquettes de la figure de Cadell, page 64 de son article
label("{\relsize{0}{$P$}}",poleSud,S);
label("{\relsize{0}{$N$}}",N,E);
label("{\relsize{0}{$H$}}",H,SE);
label("{\relsize{0}{$S$}}",Sh1[0],0.35N);
label("{\relsize{0}{$D$}}",D[0],SW);
label("{\relsize{0}{$O$}}",K1,SW);
label("{\relsize{0}{$M$}}",M,E);
