// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  name  = Dominique COLLIN
//	mail  = dnilloc@sfr.fr
//	adress= 18 rue Joseph Cadei - 06100 , Nice - France.
//	Phone = 04.93.37.69.13  portable = 06.48.85.12.62.
//  Work  = Lyce Professionnel Pasteur
//				25 rue du Professeur Delvalle - 06000, Nice.
//	date  = juin 2010.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Objet = Gnomonique thorique
// Lignes horaires Temporaires en usage dans l'antiquit.
// Traduction de l'article de W.A. CADELL (date : 1816 lecture/1818 publication).
// Reprsentation des diffrentes projections centrales des hectmories.
//
//	FIGURE DETAILLE (en PDF 3D) de la figure page 64.
//
//	PLAN TANGENT AU POLE SUD CELESTE // Projection centrale
//	Latitude : phi = 6634' Nord.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// ------------------------------------------------------------------------------------------------
// Beginning of Asymptote Figure.
// Cet en-tte permet de visualiser l'image 3D mme si le visualisation PDF ne traite pas la PRC.
// ------------------------------------------------------------------------------------------------
import settings;
	leftbutton=new string[] {"Rotation","Agrandissement","Shift","Pan"};
	middlebutton=new string[] {"Menu"};
	rightbutton=new string[] {"Agrandissement/menu","RotateX","RotateY","RotateZ"};
	wheelup=new string[] {"ZoomIn"};
	wheeldown=new string[] {"ZoomOut"};
//
 	settings.batchView=true;
 	settings.tex="pdflatex";
	settings.render=2;
	//settings.inlineimage=true;
	settings.embed=true;
	settings.outformat='pdf';
	settings.toolbar=true;
	settings.prc=true;
	viewportmargin=(1,1);
	viewportsize=(300pt,0);
	//defaultfilename='fig_Michnik_n2p4_plan-Tangent-au-Pole';
// ------------------------------------------------------------------------------------------------
// ********Appel des fichiers de macros....************************************* <----
import graph3;
import solids;
import math;
import labelpath3;
usepackage("relsize");//rgle la taille du texte...

// taille de la figure
size(15cm,0);
scale(true);

// ********REGLAGES de la vue / perspective...********************************** <----
currentprojection=orthographic(-0.00000000001,0,20);; //(2,1,1)
currentlight=White;

// ********DECLARATION des variables et des paramtres...***********************
real R, phi, epsilon, delta, L, n, k, K, delta_limite ;
R=1					; // rayon de la sphre cleste	 			  				<----
phi= 66+34/60		; // latitude gographique du lieu du cadran solaire
epsilon=23+26/60	; // obliquit de l'cliptique / valeur maximum de delta.
K=-cot(phi*pi/180)	; 
// ***************************************************************************** //
//	Les points sur la sphre
triple origine 	=	(0,0,0);	// Centre de la sphre.
triple poleNord =	(0,0,R);	// ple Nord P sur la sphre cleste.
triple poleSud  =	(0,0,-R);	// ple Sud P' sur la sphre cleste.
triple EqSud	=	(R,0,0);	// Point sud quatorial.
triple EqEst	=	(0,R,0);	// Point quatorial est.
triple Zenith   =   (R*Sin(90-phi),0,R*Sin(phi)); // Znith du lieu de latitude phi.
triple OrigineHectemories = R*(Cos(90-phi),0,-Sin(90-phi)); // Point commun  toutes les Hectmories
//
//~~~~~~~~~ CONSTRUCTION de la SPHERE CELESTE ~~~~~~~~~ 
revolution b=sphere(origine,R);
draw(surface(b),paleblue+opacity(.85));
//
//~~~~~~~~~ CONSTRUCTION du PLAN TANGENT AU PLE SUD DE LA SPHERE CELESTE ~~~~~~~~~ 
delta_limite = 12 ;
surface plantgtpol = shift(poleSud)*scale3(R*Tan(90-delta_limite))*unitdisk;
//draw(surface(plantgtpol),white);
//
// ******** CONSTRUCTIONS des HECTEMORIES SUR LA SPHERE CELESTE ~~~~~~~~~ 
//
//for (k=1 ; k<6; k=k+1) {
k=3;
n=6/k ;	// heure temporaire III (n=6/k)
real x(real t) {return R*Cos(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real y(real t) {return R*Sin(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real z(real t) {return R*K*Cos(n*t)/sqrt(1+(K*Cos(n*t))^2) 	;}

path3 ps=graph(x,y,z,0,360, operator ..);
draw(ps,0.85bp+blue,Arrow3(1));

for( L = -90 ; L < +90; L=L+1/5 ) {	// on ne trace qu'une partie des hectmories (E-Sud-W)
	delta = aTan(K*Cos(n*L));
	// Un point de l'Hectmorie sur la surface de la sphre.
	triple S = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta),  Sin(delta) );
	// On dfinit la droite (OS) pour matrialiser le principe de la projection centrale...
	path3 ligne = origine--S--10*R*S;
	// CONSTRUCTION de S2, projection centrale de S sur le plan tangent au ple de la sphre.
	triple[] S2=intersectionpoints(ligne,surface(plantgtpol));
	dot(S2,0.28mm+red);
	}
//}
//~~~~~~~~~ QUELQUES POINTS... ~~~~~~~~~~~ 
triple N=(R*Tan(90-delta_limite),0,-R);
triple H=(R*Tan(phi),0,-R) ; // point d'intersection des hectmories dans le plan Tgt.
	L=25;
	delta=aTan(-K*Cos(n*L));
triple Sh = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta), - Sin(delta) ); // point sur la sphre
path3 ligne = origine--Sh--10*R*Sh;
triple[] Sh1=intersectionpoints(ligne,surface(plantgtpol)); // point dans le plan tangent. 
//~~~~~~~~~ petits cercles ~~~~~~~~~ 
triple centre_ete = -(0,0,R*Sin(epsilon));
triple centre_hiv = -(0,0,-R*Sin(epsilon));
// CONSTRUCTION DU CERCLE HORIZON SUR LA SPHERE CELESTE.
path3 cerclehori = circle(O, R, rotate((90-phi),Y)*Z);
//	Projection centrale du solstice d't.
real R2max = R*Tan(phi);				// rayon du cercle limite boral des hectmories.
real Rsolsticeete = R*Tan(90-epsilon);	// rayon du cercle du solstice d't dans le plan.
path3 cerclemax = circle(poleSud, R2max, Z);
path3 cerclesolsticeete = circle(poleSud, Rsolsticeete, Z); //si phi=90-epsilon, les cercles max et solstice t, ont mme rayon.
//
// trac de la ligne d'horizon, projection centrale du cercle horizon..
triple K1=(R*Tan(phi), sqrt((R*Tan(90-delta_limite))^2-(R*Tan(phi))^2) ,-R);
triple K2=(R*Tan(phi), -sqrt((R*Tan(90-delta_limite))^2-(R*Tan(phi))^2) ,-R);
//
int j=45; // angle horaire vrai de la ligne de 9h...
triple Mj=(R*Tan(90-delta_limite)*Cos(j), R*Tan(90-delta_limite)*Sin(j), -R);
triple[] D=intersectionpoints(poleSud--Mj, shift(poleSud)*scale3(H.x)*unitcircle3);
triple[] Dp1=intersectionpoints(poleSud--Mj,H--K1);
triple Dp2=(sqrt(Dp1[0].x^2+Dp1[0].y^2),0,-R);
triple M=(Sh1[0].x,0,-R);
//
// Le marquage des points de la figure.
dot(origine);
dot(poleNord,2bp+green);
dot(poleSud,2bp+green);
dot(EqSud,2bp+green);
dot(EqEst,1.5bp+green);
dot(Zenith,2bp+yellow);
dot(OrigineHectemories,2.5bp+orange);
dot(R*(Cos(j)*Cos(epsilon),Sin(j)*Cos(epsilon),-Sin(epsilon)),1.8bp+orange); // un point sur le cercle horaire
dot(N,red);
dot(K1,red);
dot(K2,red);
dot(H,red);
dot(Sh,1.8bp+red);
dot(Sh1,red);
dot(M,2bp+green);
dot(D,2bp+red);
//
// le dessin des segments
draw(origine--N,black+dashed+1/4bp);		// rayon P'N.
draw(origine--H,black+dashed+1/4bp);		// rayon P'I1.
draw(origine--Sh1[0],black+dashed+1/4bp);
draw(origine--poleSud,white+dashed);
draw(origine--EqSud,white+dashed);
draw(origine--D[0],black+dashed+1/4bp);
draw(poleSud--N,black+1/4bp,Arrow3);
draw(poleSud--Mj,black);
draw(poleSud--Sh1[0],black);
draw(M--Sh1[0],1/3bp+black);
draw(H--Sh1[0],black);
draw(K1--K2,black); // horizon dans la projection centrale
//
// ARCS de grand cercle et petits cercles de la sphre cleste.
draw(scale3(R)*unitcircle3,1.25red); 							// cercle equatorial
draw(arc(origine, poleNord, OrigineHectemories, CCW),1.5bp+red);// mridien
draw(arc(origine, poleNord, Sh, CCW),2green);					// arc jusqu' l'hectmorie
draw(arc(origine, poleNord, R*(Cos(j)*Cos(epsilon),Sin(j)*Cos(epsilon),-Sin(epsilon)), CCW),black); // arc horaire (9h)
draw(cerclehori,0.75bp+3yellow);								// cercle de l'horizon
draw(shift(centre_hiv)*scale3(R*Cos(epsilon))*unitcircle3,0.65bp+dashed+1.5yellow);// colure hiver
draw(shift(centre_ete)*scale3(R*Cos(epsilon))*unitcircle3,0.65bp+dashed+1.5yellow);// colure t
draw(shift((0,0,-R*Sin(delta_limite)))*scale3(R*Cos(delta_limite))*unitcircle3,1/4bp+dashed+1.5yellow);// arc diurne de 10...
// CERCLES dans le plan tangent au pole sud de la sphre cleste.
draw(shift(poleSud)*scale3(N.x)*unitcircle3,black); // juste pour dlimiter les projections des hectmories
draw(shift(poleSud)*scale3(R*Tan(90-delta))*unitcircle3,black);
draw(shift(poleSud)*scale3(H.x)*unitcircle3,1/4bp+red+dashed);// cercle de rayon P'H.
draw(shift(poleSud)*scale3(R)*unitcircle3,orange+dashed);// cercle de rayon le rayon de la sphre cleste
//
// Les tiquettes de la figure de Cadell, page 64 de son article
label("{\relsize{-2}{$O$}}",origine,NW);
label("{\relsize{-2}{$P_N$}}",poleNord,0.4NW);
label("{\relsize{-2}{$Z$}}",Zenith,0.4N);
label("{\relsize{-2}{$E$}}",EqSud,NW);
label("{\relsize{-2}{$Est$}}",EqEst,NW);
label("{\relsize{-2}{$I$}}",OrigineHectemories,NW);

label("{\relsize{0}{$P$}}",poleSud,S);
label("{\relsize{0}{$N$}}",N,E);
label("{\relsize{0}{$H$}}",H,SE);
label("{\relsize{0}{$S$}}",Sh1[0],0.35N);
label("{\relsize{0}{$D$}}",D[0],SW);
label("{\relsize{0}{$O$}}",K1,SW);
label("{\relsize{0}{$M$}}",M,E);

//
// Le repre Oxyz...
limits(O,5*R*X+5*R*Y+1.6*R*Z);
axes3("$x$","$y$","$z$",Arrow3);
