// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  name  = Dominique COLLIN
//	mail  = dnilloc@sfr.fr
//	adress= 18 rue Joseph Cadei - 06100 , Nice - France.
//	Phone = 04.93.37.69.13  portable = 06.48.85.12.62.
//  Work  = Lyce Professionnel Pasteur
//			25 rue du Professeur Delvalle - 06000, Nice.
//	date  = juin 2010.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Objet = Gnomonique thorique
// Lignes horaires Temporaires en usage dans l'antiquit.
// Traduction de l'article de W.A. CADELL (date : 1816 lecture/1818 publication).
// Reprsentation des diffrentes projections centrales des hectmories.
//
//	FIGURE (en PDF 3D) de la figure page 66.
//
//	PLAN TANGENT AU POLE SUD CELESTE // Projection centrale
//	Latitude : variant de 30  70 Nord.

// ------------------------------------------------------------------------------------------------
// Begining of Asymptote Figure.
// Cet en-tte permet de visualiser l'image 3D mme si le visualisation PDF ne traite pas la PRC.
// ------------------------------------------------------------------------------------------------
import settings;
	leftbutton=new string[] {"Rotation","Agrandissement","Shift","Pan"};
	middlebutton=new string[] {"Menu"};
	rightbutton=new string[] {"Agrandissement/menu","RotateX","RotateY","RotateZ"};
	wheelup=new string[] {"ZoomIn"};
	wheeldown=new string[] {"ZoomOut"};
//
 	settings.batchView=true;
 	settings.tex="pdflatex";
	settings.render=2;
	//settings.inlineimage=true;
	settings.embed=true;
	settings.outformat='pdf';
	settings.toolbar=true;
	settings.prc=true;
	viewportmargin=(1,1);
	viewportsize=(300pt,0);
	//defaultfilename='fig_Michnik_n2p4_plan-Tangent-au-Pole';
// ------------------------------------------------------------------------------------------------
// ********Appel des fichiers de macros....************************************* <----
import graph3;
import solids;
import math;
import labelpath3;
usepackage("relsize");//rgle la taille du texte...

// taille de la figure
size(15cm,0);
scale(true);

// ********REGLAGES de la vue / perspective...********************************** <----
currentprojection=orthographic(-0.00000000001,0,20);; //(2,1,1)
currentlight=White;

// ********DECLARATION des variables et des paramtres...***********************
real R, phi, epsilon, delta, L, n, k, K, delta_limite ;
R=1					; // rayon de la sphre cleste	 			  				<----
phi= 66+34/60		; // latitude gographique du lieu du cadran solaire
epsilon=23+26/60	; // obliquit de l'cliptique / valeur maximum de delta.
K=-cot(phi*pi/180)	; 
// ***************************************************************************** //
//	Les points sur la sphre
triple origine 	=	(0,0,0);	// Centre de la sphre.
triple poleNord =	(0,0,R);	// ple Nord P sur la sphre cleste.
triple poleSud  =	(0,0,-R);	// ple Sud P' sur la sphre cleste.
triple EqSud	=	(R,0,0);	// Point sud quatorial.
triple EqEst	=	(0,R,0);	// Point quatorial est.
triple Zenith   =   (R*Sin(90-phi),0,R*Sin(phi)); // Znith du lieu de latitude phi.
triple OrigineHectemories = R*(Cos(90-phi),0,-Sin(90-phi)); // Point commun  toutes les Hectmories
//
//~~~~~~~~~ CONSTRUCTION de la SPHERE CELESTE ~~~~~~~~~ 
revolution b=sphere(origine,R);
//draw(surface(b),paleblue+opacity(.85));
//
//~~~~~~~~~ CONSTRUCTION du PLAN TANGENT AU PLE SUD DE LA SPHERE CELESTE ~~~~~~~~~ 
delta_limite = 12 ;
surface plantgtpol = shift(poleSud)*scale3(R*Tan(90-delta_limite))*unitdisk;
//draw(surface(plantgtpol),white);
//
int j=45;
triple Mj1=(R*Tan(90-delta_limite)*Cos(j), R*Tan(90-delta_limite)*Sin(j), -R);
triple Mj2=(R*Tan(90-delta_limite)*Cos(-j), R*Tan(90-delta_limite)*Sin(-j), -R);
draw(poleSud--Mj1,black);
draw(poleSud--Mj2,black);
//
// ******** CONSTRUCTIONS des HECTEMORIES SUR LA SPHERE CELESTE ~~~~~~~~~ 
//
for(phi=10;phi<80;phi=phi+10) { //
K=-cot(phi*pi/180)	; 
k=3;
n=6/k ;	// heure temporaire III (n=6/k)
	for( L = -90 ; L < +90; L=L+1/8 ) {	// on ne trace qu'une partie des hectmories (E-Sud-W)
		delta = aTan(K*Cos(n*L));
		// Un point de l'Hectmorie sur la surface de la sphre.
		triple S = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta),  Sin(delta) );
		// On dfinit la droite (OS) pour matrialiser le principe de la projection centrale...
		path3 ligne = origine--S--10*R*S;
		// CONSTRUCTION de S2, projection centrale de S sur le plan tangent au ple de la sphre.
		triple[] S2=intersectionpoints(ligne,surface(plantgtpol));
		dot(S2,0.28mm+heavyblue);
	}
}
//~~~~~~~~~ QUELQUES POINTS... ~~~~~~~~~~~ 
//
// Le marquage des points de la figure.
dot(poleSud,2bp+green);
//
// Les tiquettes de la figure de Cadell, page 64 de son article
label("{\relsize{0}{$P$}}",poleSud,S);