// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//  name  = Dominique COLLIN
//	mail  = dnilloc@sfr.fr
//	adress= 18 rue Joseph Cadei - 06100 , Nice - France.
//	Phone = 04.93.37.69.13  portable = 06.48.85.12.62.
//  Work  = Lyce Professionnel Pasteur
//				25 rue du Professeur Delvalle - 06000, Nice.
//	date  = juin 2010.
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// Objet = Gnomonique thorique
// Lignes horaires Temporaires en usage dans l'antiquit.
// Traduction de l'article de W.A. CADELL (date : 1816 lecture/1818 publication).
// Reprsentation des diffrentes projections centrales des hectmories.
//
//	FIGURE DETAILLE (en PDF 3D) de la figure page 64.
//
//	PLAN TANGENT AU POLE SUD CELESTE // Projection centrale
//	Latitude : phi = 6634' Nord.
// ------------------------------------------------------------------------------------------------
// Begining of Asymptote Figure.
// Cet en-tte permet de visualiser l'image 3D mme si le visualisation PDF ne traite pas la PRC.
// ------------------------------------------------------------------------------------------------
import settings;
	leftbutton=new string[] {"Rotation","Agrandissement","Shift","Pan"};
	middlebutton=new string[] {"Menu"};
	rightbutton=new string[] {"Agrandissement/menu","RotateX","RotateY","RotateZ"};
	wheelup=new string[] {"ZoomIn"};
	wheeldown=new string[] {"ZoomOut"};
//
 	settings.batchView=true;
 	settings.tex="pdflatex";
	settings.render=2;
	//settings.inlineimage=true;
	settings.embed=true;
	settings.outformat='pdf';
	settings.toolbar=true;
	settings.prc=true;
	viewportmargin=(1,1);
	viewportsize=(300pt,0);
	//defaultfilename='fig_Michnik_n2p4_plan-Tangent-au-Pole';
// ------------------------------------------------------------------------------------------------
// ********Appel des fichiers de macros....************************************* <----
import graph3;
import solids;
import math;
import labelpath3;
usepackage("relsize");//rgle la taille du texte...

// taille de la figure
size(15cm,0);
scale(true);

// ********REGLAGES de la vue / perspective...********************************** <----
currentprojection=orthographic(-0.00000000001,0,20);; //(2,1,1)
currentlight=White;

// ********DECLARATION des variables et des paramtres...***********************
real R, phi, epsilon, delta, L, n, k, K, delta_limite ;
R=1					; // rayon de la sphre cleste	 			  				<----
phi= 43+43/60		; // latitude gographique du lieu du cadran solaire
epsilon=23+26/60	; // obliquit de l'cliptique / valeur maximum de delta.
K=-cot(phi*pi/180)	; 
// ***************************************************************************** //
//	Les points sur la sphre
triple origine 	=	(0,0,0);	// Centre de la sphre.
triple poleNord =	(0,0,R);	// ple Nord P sur la sphre cleste.
triple poleSud  =	(0,0,-R);	// ple Sud P' sur la sphre cleste.
triple EqSud	=	(R,0,0);	// Point sud quatorial.
triple EqEst	=	(0,R,0);	// Point quatorial est.
triple Zenith   =   (R*Sin(90-phi),0,R*Sin(phi)); // Znith du lieu de latitude phi.
triple OrigineHectemories = R*(Cos(90-phi),0,-Sin(90-phi)); // Point commun  toutes les Hectmories
//
//~~~~~~~~~ CONSTRUCTION de la SPHERE CELESTE ~~~~~~~~~ 
revolution b=sphere(origine,R);
//draw(surface(b),paleblue+opacity(.85));
//
//~~~~~~~~~ CONSTRUCTION du PLAN TANGENT AU PLE SUD DE LA SPHERE CELESTE ~~~~~~~~~ 
delta_limite = 17 ;
surface plantgtpol1 = shift(poleSud)*scale3(R*Tan(90-delta_limite))*unitdisk;
surface plantgtpol2 = shift(poleNord)*scale3(R*Tan(90-delta_limite))*unitdisk;
//draw(surface(plantgtpol),white);
//
// ******** CONSTRUCTIONS des HECTEMORIES SUR LA SPHERE CELESTE ~~~~~~~~~ 
//
//for (k=1 ; k<6; k=k+1) {
k=3;
n=6/k ;	// heure temporaire III (n=6/k)
real x(real t) {return R*Cos(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real y(real t) {return R*Sin(t)/sqrt(1+(K*Cos(n*t))^2) 		;}
real z(real t) {return R*K*Cos(n*t)/sqrt(1+(K*Cos(n*t))^2) 	;}

path3 ps=graph(x,y,z,0,360, operator ..);
//draw(ps,0.85bp+blue,Arrow3(1));

for( L = 0 ; L < +360; L=L+1/5 ) {	// on ne trace qu'une partie des hectmories (E-Sud-W)
	delta = aTan(K*Cos(n*L));
	// Un point de l'Hectmorie sur la surface de la sphre.
	triple S = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta),  Sin(delta) );
	// On dfinit la droite (OS) pour matrialiser le principe de la projection centrale...
	path3 ligne = origine--S--10*R*S;
	// CONSTRUCTION de S2, projection centrale de S sur le plan tangent aux ples de la sphre.
	triple[] S2=intersectionpoints(ligne,surface(plantgtpol1));
	triple[] S3=intersectionpoints(ligne,surface(plantgtpol2));
	dot(S2,0.28mm+red);
	dot(S3,0.28mm+blue);
	}
//}
//~~~~~~~~~ QUELQUES POINTS... ~~~~~~~~~~~ 
triple N=(R*Tan(90-delta_limite),0,-R);
triple H=(R*Tan(phi),0,-R) ; // point d'intersection des hectmories dans le plan Tgt.
	L=25;
	delta=aTan(-K*Cos(n*L));
triple Sh = R*( Cos(L)*Cos(delta),Sin(L)*Cos(delta), - Sin(delta) ); // point sur la sphre
path3 ligne = origine--Sh--10*R*Sh;
triple[] Sh1=intersectionpoints(ligne,surface(plantgtpol1)); // point dans le plan tangent. 
//~~~~~~~~~ petits cercles ~~~~~~~~~ 
triple centre_ete = -(0,0,R*Sin(epsilon));
triple centre_hiv = -(0,0,-R*Sin(epsilon));
// CONSTRUCTION DU CERCLE HORIZON SUR LA SPHERE CELESTE.
path3 cerclehori = circle(O, R, rotate((90-phi),Y)*Z);
//	Projection centrale du solstice d't.
real R2max = R*Tan(phi);				// rayon du cercle limite boral des hectmories.
real Rsolsticeete = R*Tan(90-epsilon);	// rayon du cercle du solstice d't dans le plan.
path3 cerclemax = circle(poleSud, R2max, Z);
path3 cerclesolsticeete = circle(poleSud, Rsolsticeete, Z); //si phi=90-epsilon, les cercles max et solstice t, ont mme rayon.
//
int j=45; // angle horaire vrai de la ligne de 9h...
triple Mja=(R*Tan(90-delta_limite)*Cos(j), R*Tan(90-delta_limite)*Sin(j), -R);
triple Mjb=(R*Tan(90-delta_limite)*Cos(j), -R*Tan(90-delta_limite)*Sin(j), -R);
triple Mjc=(-R*Tan(90-delta_limite)*Cos(j), -R*Tan(90-delta_limite)*Sin(j), -R);
triple Mjd=(-R*Tan(90-delta_limite)*Cos(j), R*Tan(90-delta_limite)*Sin(j), -R);
//
// Le marquage des points de la figure.
dot(origine);
dot(poleNord,2bp+green);
dot(poleSud,2bp+green);
//
// le dessin des segments
draw(origine--poleSud,white+dashed);
draw(origine--EqSud,white+dashed);
draw(Mja--Mjc,black);
draw(Mjb--Mjd,black);
//
// ARCS de grand cercle et petits cercles de la sphre cleste.
// Les tiquettes de la figure de Cadell, page 64 de son article
//label("{\relsize{-2}{$O$}}",origine,NW);
//label("{\relsize{-2}{$P^\prime$}}",poleNord,0.4NW);

label("{\relsize{0}{$P^\prime$}}",poleSud,1.1W);